#
# Copyright (c) 2008-2019 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

from zope.container.constraints import contains
from zope.container.interfaces import IContainer
from zope.interface import Interface
from zope.location.interfaces import IContained
from zope.schema import Bool, Choice, Set

from onf_website.reference.insee.schema import CommunesListField
from onf_website.reference.orga.schema import StructuresListField
from onf_website.shared.contact.interfaces.theme import CONTACT_THEMES_VOCABULARY
from pyams_utils.schema import MailAddressField

from onf_website import _


class IContactAssignment(Interface):
    """Contact assignments interfaces"""

    active = Bool(title=_("Active assignment?"),
                  required=True,
                  default=True)

    theme = Choice(title=_("Contact theme"),
                   description=_("Theme matching this assignment"),
                   vocabulary=CONTACT_THEMES_VOCABULARY,
                   required=True)

    cities = CommunesListField(title=_("Cities"),
                               required=False)

    departments = Set(title=_("Departments"),
                      value_type=Choice(vocabulary='ONF regions with departments'),
                      required=False)

    structures = StructuresListField(title=_("Structures"),
                                     required=False)

    mail_address = MailAddressField(title=_("Mail address"),
                                    description=_("Alternate email address for this assignment, "
                                                  "without '<' or '>'"),
                                    required=False)

    def get_theme(self):
        """Get contact theme associated with this assignment"""

    def is_matching(self, postal_code):
        """Returns a boolean value to check if given postal code is matching any assignment locations"""


CONTACT_ASSIGNMENTS_ANNOTATION_KEY = 'onf_website.contact.assignments'


class IContactAssignmentsContainer(IContainer, IContained):
    """Contact assignments manager interface"""

    contains(IContactAssignment)

    def get_active_assignments(self):
        """Get currently active assignments"""

    def get_matching_assignment(self, theme, postal_code):
        """Returns any assignment matching given themes and postal codes, or None

        :param str theme: input theme; can also be an :ref:`IContactTheme` object
        :param str postal_code: postal code for which we are looking for an assignment
        :return IContactAssignment: any assignment matching given arguments
        """
