#
# Copyright (c) 2008-2019 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

from zope.annotation import IAttributeAnnotatable
from zope.schema import TextLine

from pyams_content.shared.form.interfaces import IFormHandlerInfo
from pyams_utils.schema import MailAddressField


__docformat__ = 'restructuredtext'

from onf_website import _


CONTACT_FORM_HANDLER_ANNOTATIONS_KEY = 'onf_website.contact.form.handler'


class IContactFormHandlerInfo(IFormHandlerInfo):
    """Contact form handler info"""

    crm_source = TextLine(title=_("CRM source"),
                          description=_("If this contact form is supposed to match a CRM source, please "
                                        "enter it here"),
                          required=False)

    source_address = MailAddressField(title=_("Source address"),
                                      description=_("Mail address from which form data is sent"),
                                      required=False)

    source_name = TextLine(title=_("Source name"),
                           description=_("Name of mail data sender"),
                           required=False)

    target_address = MailAddressField(title=_("Recipient address"),
                                      description=_("Mail address to which form data is systematically sent"),
                                      required=False)

    target_name = TextLine(title=_("Recipient name"),
                           description=_("Name of data recipient"),
                           required=False)


class IContactFormHandlerTarget(IAttributeAnnotatable):
    """Contact form handler target marker interface"""
