#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from zope.interface import Interface

from pyams_i18n.schema import I18nTextLineField, I18nTextField
from pyams_sequence.schema import InternalReferenceField

from onf_website import _


class IONFViewItemsPortletNewsRendererSettings(Interface):
    """View items portlet news renderer settings interface"""

    list_reference = InternalReferenceField(title=_("'All news' reference"),
                                            description=_("Internal reference to site or folder "
                                                          "displaying full list of view's contents"),
                                            required=False)

    def get_target(self):
        """Get internal reference target"""

    link_label = I18nTextLineField(title=_("Link label"),
                                   description=_("Label of link to full list page"),
                                   required=False)


class IONFViewItemsPortletCarouselRendererSettings(Interface):
    """View items portlet carousel renderer settings interface"""

    header = I18nTextField(title=_("Header"),
                           description=_("Menu header displayed by front-office template"),
                           required=False)

    button_label = I18nTextLineField(title=_("Button label"),
                                     description=_("Label of the navigation button displayed by "
                                                   "front-office template"),
                                     required=False)

    button_target = InternalReferenceField(title=_("Button target"),
                                           description=_("Internal reference to site or folder "
                                                         "targetted by button"),
                                           required=False)
